@@ -118,7 +118,7 @@ fixLMtps <- function(data,comp=3,weight=TRUE,weightfun=NULL)
       miss <- checklist[[check[i]]]
       if (weight && ngood > 1) { ### calculate weighted estimates of missing data ###
           ## rotate incomplete data onto mean ###
-          rotmiss <- rotonto(mean0[-miss,],data[-miss,,check[i]],scale=TRUE)$yrot
+          rotmiss <- rotonto(mean0[-miss,],data[-miss,,check[i]],scale=TRUE,reflection = FALSE)$yrot
           allrot <- bindArr(rotmiss,proc.c$rotated[-miss,,], along=3)
           ## calculate weights according to procrustes distance ###			
           wcalc <- proc.weight(allrot,comp,1,report=FALSE,weightfun=weightfun)
